/*
Copyright 2006 Frank van der Loo

This file is part of Paratim.

Paratim is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Paratim is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Paratim; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "plane.h"
#include "bomb.h"

// Creates a new plane that flies to the left
planel::planel(/*int x*/) : sprite(DATADIR, "/airplane2.bmp")
{
	dst.x = 800;
	dst.y = 5;
	dst.w = image->w;
	dst.h = image->h;
	black.w = image->w + 3;
	black.h = image->h + 3;
	black.x = dst.x - 3;
	black.y = dst.y - 3;
	points = 10;
	end = false;
	bombdrop_x = (rand()%250)+450;
}

// Moves the plane a few pixels to the left
void planel::move()
{
	//std::cout << "\nplanel:\ndst.x: " << dst.x << "\ndst.y: " << dst.y << std::endl;
	if (dst.x < 0-image->w)
	{
		end = true;
		return;
	}
	dst.x-=3;
	black.x = dst.x - 1;
}

// Lets the plane drop a bomb
bool planel::drop_bomb()
{
	if (dst.x <= bombdrop_x && dst.x > bombdrop_x-3)
		return true;
	return false;
}


// Creates a plane that file to the right
planer::planer(/*int x*/) : sprite(DATADIR, "/airplane.bmp")
{
	dst.x = 0 - image->w;			//CHANGE!!!!!!!!!
	dst.y = 5;
	dst.w = image->w;
	dst.h = image->h;
	black.w = image->w + 3;
	black.h = image->h + 3;
	black.x = dst.x - 3;
	black.y = dst.y - 3;
	points = 10;
	end = false;
	bombdrop_x = (rand()%250)+50;
}

// Moves the plane a few pixels to the right
void planer::move()
{
	//std::cout << "\nplaner:\ndst.x: " << dst.x << "\ndst.y: " << dst.y << std::endl;
	if (dst.x > 800)
	{
		end = true;
		return;
	}
	dst.x+=3;
	black.x = dst.x - 1;
}

// Lets the plane drop a bomb
bool planer::drop_bomb()
{
	if (dst.x >= bombdrop_x && dst.x < bombdrop_x+3)
		return true;
	return false;
}

// Moves the planes
void move_plane(SDL_Surface *screen, planel *airplanel, planer *airplaner, bomb *plane_bomb)
{
	if (airplanel)
	{
		SDL_Rect planeblack = airplanel->getBlack();
		SDL_FillRect(screen, &planeblack, SDL_MapRGB(screen->format, 0, 0, 0));
		if (!airplanel->getEnd())
			airplanel->move();
		SDL_Rect planetemp = airplanel->getDstRect();
		//std::cout << "\nplanetemp.x: " << planetemp.x;
		//std::cout << "\nplanetemp.y: " << planetemp.y;
		//std::cout << "\nplanetemp.h: " << planetemp.h;
		//std::cout << "\nplanetemp.w: " << planetemp.w << std::endl;
		SDL_BlitSurface(airplanel->getSurface(), NULL, screen, &planetemp);
		if (airplanel->drop_bomb())
		{
			plane_bomb->init_bomb((airplanel->getDstRect()).x, (airplanel->getDstRect()).y);
		}
	}
	else if (airplaner)
	{
		SDL_Rect planeblack = airplaner->getBlack();
		SDL_FillRect(screen, &planeblack, SDL_MapRGB(screen->format, 0, 0, 0));
		if (!airplaner->getEnd())
			airplaner->move();
		SDL_Rect planetemp = airplaner->getDstRect();
		SDL_BlitSurface(airplaner->getSurface(), NULL, screen, &planetemp);
		if (airplaner->drop_bomb())
		{
			plane_bomb->init_bomb((airplaner->getDstRect()).x, (airplaner->getDstRect()).y);
		}
	}
}

// Return the number of planes that will be sent
int get_num_of_planes()
{
	int num_of_planes = rand()%5 + 1;
	#ifdef DEBUG
	std::cout << "\nNum_of_planes: " << num_of_planes << std::endl;
	#endif
	return num_of_planes;
}

// Load the planes that will be used in their array
void set_planes(planel *left_planes[], planer *right_planes[], int num_of_planes)
{
	for (int i=0;i<num_of_planes;i++)
	{
		if ((rand()%2 + 1) == 1)
			left_planes[i] = new planel();
		else
			right_planes[i] = new planer();
	}
}
